==> apache-ignite-3.0.0-src.zip: apache-ignite-3.0.0-src/modules/replicator/src/main/java/org/apache/ignite/internal/replicator/message/ZonePartitionIdMessage.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.replicator.message;

import org.apache.ignite.internal.network.annotations.Transferable;
import org.apache.ignite.internal.replicator.ReplicationGroupId;
import org.apache.ignite.internal.replicator.ZonePartitionId;

/** Message for transferring a {@link ZonePartitionId}. */
@Transferable(ReplicaMessageGroup.ZONE_PARTITION_ID_MESSAGE)
public interface ZonePartitionIdMessage extends ReplicationGroupIdMessage {
    /** Zone ID. */
    int zoneId();

    /** Table ID. */
    int tableId();

    /** Partition ID. */
    int partitionId();

    /** Converts to {@link ZonePartitionId}. */
    default ZonePartitionId asZonePartitionId() {
        return new ZonePartitionId(zoneId(), tableId(), partitionId());
    }

    @Override
    default ReplicationGroupId asReplicationGroupId() {
        return asZonePartitionId();
    }
}

==> apache-ignite-3.1.0-src.zip: apache-ignite-3.1.0-src/modules/replicator/src/main/java/org/apache/ignite/internal/replicator/message/ZonePartitionIdMessage.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.replicator.message;

import org.apache.ignite.internal.network.annotations.Transferable;
import org.apache.ignite.internal.replicator.ReplicationGroupId;
import org.apache.ignite.internal.replicator.ZonePartitionId;

/** Message for transferring a {@link ZonePartitionId}. */
@Transferable(ReplicaMessageGroup.ZONE_PARTITION_ID_MESSAGE)
public interface ZonePartitionIdMessage extends ReplicationGroupIdMessage {
    /** Zone ID. */
    int zoneId();

    /** Partition ID. */
    int partitionId();

    /** Converts to {@link ZonePartitionId}. */
    default ZonePartitionId asZonePartitionId() {
        return new ZonePartitionId(zoneId(), partitionId());
    }

    @Override
    default ReplicationGroupId asReplicationGroupId() {
        return asZonePartitionId();
    }
}
